==> ghc5_5.02.2.orig.tar.gz: ghc5-5.02.2.orig/hslibs/win32/Win32Graphics2D_stub_ffi.h <==
#include "HsFFI.h"
extern void* prim_moveToEx(HDC arg1,int arg2,int arg3);
extern LONG access_prim_moveToEx_gc_res2(HsPtr);
extern LONG access_prim_moveToEx_gc_res4(HsPtr);
extern int access_prim_moveToEx_gc_failed(HsPtr);
extern void* access_prim_moveToEx_gc_failstring(HsPtr);
extern void* prim_lineTo(HDC arg1,int arg2,int arg3);
extern int access_prim_lineTo_gc_failed(HsPtr);
extern void* access_prim_lineTo_gc_failstring(HsPtr);
extern void* prim_polyline(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyline_gc_failed(HsPtr);
extern void* access_prim_polyline_gc_failstring(HsPtr);
extern void* prim_polylineTo(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polylineTo_gc_failed(HsPtr);
extern void* access_prim_polylineTo_gc_failstring(HsPtr);
extern void* prim_polygon(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polygon_gc_failed(HsPtr);
extern void* access_prim_polygon_gc_failstring(HsPtr);
extern void* prim_polyBezier(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyBezier_gc_failed(HsPtr);
extern void* access_prim_polyBezier_gc_failstring(HsPtr);
extern void* prim_polyBezierTo(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyBezierTo_gc_failed(HsPtr);
extern void* access_prim_polyBezierTo_gc_failstring(HsPtr);
extern void* prim_fillRect(HDC arg1,LONG gc_arg3,LONG gc_arg5,LONG gc_arg7,LONG gc_arg9,HBRUSH arg3);
extern int access_prim_fillRect_gc_failed(HsPtr);
extern void* access_prim_fillRect_gc_failstring(HsPtr);
extern void* prim_frameRect(HDC arg1,LONG gc_arg3,LONG gc_arg5,LONG gc_arg7,LONG gc_arg9,HBRUSH arg3);
extern int access_prim_frameRect_gc_failed(HsPtr);
extern void* access_prim_frameRect_gc_failstring(HsPtr);
extern void* prim_invertRect(HDC arg1,LONG gc_arg3,LONG gc_arg5,LONG gc_arg7,LONG gc_arg9);
extern int access_prim_invertRect_gc_failed(HsPtr);
extern void* access_prim_invertRect_gc_failstring(HsPtr);
extern void* prim_rectangle(HDC arg1,int arg2,int arg3,int arg4,int arg5);
extern int access_prim_rectangle_gc_failed(HsPtr);
extern void* access_prim_rectangle_gc_failstring(HsPtr);
extern void* prim_roundRect(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7);
extern int access_prim_roundRect_gc_failed(HsPtr);
extern void* access_prim_roundRect_gc_failstring(HsPtr);
extern void* prim_ellipse(HDC arg1,int arg2,int arg3,int arg4,int arg5);
extern int access_prim_ellipse_gc_failed(HsPtr);
extern void* access_prim_ellipse_gc_failstring(HsPtr);
extern void* prim_arc(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_arc_gc_failed(HsPtr);
extern void* access_prim_arc_gc_failstring(HsPtr);
extern void* prim_arcTo(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_arcTo_gc_failed(HsPtr);
extern void* access_prim_arcTo_gc_failstring(HsPtr);
extern void* prim_angleArc(HDC arg1,int arg2,int arg3,WORD arg4,double arg5,double arg6);
extern int access_prim_angleArc_gc_failed(HsPtr);
extern void* access_prim_angleArc_gc_failstring(HsPtr);
extern void* prim_chord(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_chord_gc_failed(HsPtr);
extern void* access_prim_chord_gc_failstring(HsPtr);
extern void* prim_pie(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_pie_gc_failed(HsPtr);
extern void* access_prim_pie_gc_failstring(HsPtr);
extern void* prim_bitBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,unsigned int arg9);
extern int access_prim_bitBlt_gc_failed(HsPtr);
extern void* access_prim_bitBlt_gc_failstring(HsPtr);
extern void* prim_maskBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,HBITMAP arg9,INT arg10,INT arg11,unsigned int arg12);
extern int access_prim_maskBlt_gc_failed(HsPtr);
extern void* access_prim_maskBlt_gc_failstring(HsPtr);
extern void* prim_stretchBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,INT arg9,INT arg10,unsigned int arg11);
extern int access_prim_stretchBlt_gc_failed(HsPtr);
extern void* access_prim_stretchBlt_gc_failstring(HsPtr);
extern void* prim_plgBlt(HDC arg1,LONG gc_arg3,LONG gc_arg5,LONG gc_arg9,LONG gc_arg11,LONG gc_arg14,LONG gc_arg16,HDC arg2,INT x,INT y,INT w,INT h,HBITMAP bm,INT sx,INT sy);
extern int access_prim_plgBlt_gc_failed(HsPtr);
extern void* access_prim_plgBlt_gc_failstring(HsPtr);
extern void* prim_textOut(HDC arg1,INT arg2,INT arg3,char * arg4,int arg5);
extern int access_prim_textOut_gc_failed(HsPtr);
extern void* access_prim_textOut_gc_failstring(HsPtr);
extern void* prim_getTextExtentPoint32(HDC hdc,char * str,int l);
extern LONG access_prim_getTextExtentPoint32_gc_res2(HsPtr);
extern LONG access_prim_getTextExtentPoint32_gc_res4(HsPtr);
extern int access_prim_getTextExtentPoint32_gc_failed(HsPtr);
extern void* access_prim_getTextExtentPoint32_gc_failstring(HsPtr);

==> ghc6_6.2.2.orig.tar.gz: ghc6-6.2.2/hslibs/win32/Win32Graphics2D_stub_ffi.h <==
#include <windows.h>
#include "errors.h"
#include "win32debug.h"
#include "HsFFI.h"
extern void* prim_moveToEx(HDC arg1,int arg2,int arg3);
extern LONG access_prim_moveToEx_gc_res1(HsPtr);
extern LONG access_prim_moveToEx_gc_res2(HsPtr);
extern int access_prim_moveToEx_gc_failed(HsPtr);
extern void* access_prim_moveToEx_gc_failstring(HsPtr);
extern void* prim_lineTo(HDC arg1,int arg2,int arg3);
extern int access_prim_lineTo_gc_failed(HsPtr);
extern void* access_prim_lineTo_gc_failstring(HsPtr);
extern void* prim_polyline(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyline_gc_failed(HsPtr);
extern void* access_prim_polyline_gc_failstring(HsPtr);
extern void* prim_polylineTo(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polylineTo_gc_failed(HsPtr);
extern void* access_prim_polylineTo_gc_failstring(HsPtr);
extern void* prim_polygon(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polygon_gc_failed(HsPtr);
extern void* access_prim_polygon_gc_failstring(HsPtr);
extern void* prim_polyBezier(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyBezier_gc_failed(HsPtr);
extern void* access_prim_polyBezier_gc_failstring(HsPtr);
extern void* prim_polyBezierTo(HDC hdc,POINT * ps,int num_ps);
extern int access_prim_polyBezierTo_gc_failed(HsPtr);
extern void* access_prim_polyBezierTo_gc_failstring(HsPtr);
extern void* prim_fillRect(HDC arg1,LONG gc_arg2,LONG gc_arg3,LONG gc_arg4,LONG gc_arg5,HBRUSH arg3);
extern int access_prim_fillRect_gc_failed(HsPtr);
extern void* access_prim_fillRect_gc_failstring(HsPtr);
extern void* prim_frameRect(HDC arg1,LONG gc_arg2,LONG gc_arg3,LONG gc_arg4,LONG gc_arg5,HBRUSH arg3);
extern int access_prim_frameRect_gc_failed(HsPtr);
extern void* access_prim_frameRect_gc_failstring(HsPtr);
extern void* prim_invertRect(HDC arg1,LONG gc_arg2,LONG gc_arg3,LONG gc_arg4,LONG gc_arg5);
extern int access_prim_invertRect_gc_failed(HsPtr);
extern void* access_prim_invertRect_gc_failstring(HsPtr);
extern void* prim_rectangle(HDC arg1,int arg2,int arg3,int arg4,int arg5);
extern int access_prim_rectangle_gc_failed(HsPtr);
extern void* access_prim_rectangle_gc_failstring(HsPtr);
extern void* prim_roundRect(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7);
extern int access_prim_roundRect_gc_failed(HsPtr);
extern void* access_prim_roundRect_gc_failstring(HsPtr);
extern void* prim_ellipse(HDC arg1,int arg2,int arg3,int arg4,int arg5);
extern int access_prim_ellipse_gc_failed(HsPtr);
extern void* access_prim_ellipse_gc_failstring(HsPtr);
extern void* prim_arc(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_arc_gc_failed(HsPtr);
extern void* access_prim_arc_gc_failstring(HsPtr);
extern void* prim_arcTo(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_arcTo_gc_failed(HsPtr);
extern void* access_prim_arcTo_gc_failstring(HsPtr);
extern void* prim_angleArc(HDC arg1,int arg2,int arg3,WORD arg4,double arg5,double arg6);
extern int access_prim_angleArc_gc_failed(HsPtr);
extern void* access_prim_angleArc_gc_failstring(HsPtr);
extern void* prim_chord(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_chord_gc_failed(HsPtr);
extern void* access_prim_chord_gc_failstring(HsPtr);
extern void* prim_pie(HDC arg1,int arg2,int arg3,int arg4,int arg5,int arg6,int arg7,int arg8,int arg9);
extern int access_prim_pie_gc_failed(HsPtr);
extern void* access_prim_pie_gc_failstring(HsPtr);
extern void* prim_bitBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,unsigned int arg9);
extern int access_prim_bitBlt_gc_failed(HsPtr);
extern void* access_prim_bitBlt_gc_failstring(HsPtr);
extern void* prim_maskBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,HBITMAP arg9,INT arg10,INT arg11,unsigned int arg12);
extern int access_prim_maskBlt_gc_failed(HsPtr);
extern void* access_prim_maskBlt_gc_failstring(HsPtr);
extern void* prim_stretchBlt(HDC arg1,INT arg2,INT arg3,INT arg4,INT arg5,HDC arg6,INT arg7,INT arg8,INT arg9,INT arg10,unsigned int arg11);
extern int access_prim_stretchBlt_gc_failed(HsPtr);
extern void* access_prim_stretchBlt_gc_failstring(HsPtr);
extern void* prim_plgBlt(HDC arg1,LONG gc_arg2,LONG gc_arg3,LONG gc_arg6,LONG gc_arg7,LONG gc_arg9,LONG gc_arg10,HDC arg2,INT x,INT y,INT w,INT h,HBITMAP bm,INT sx,INT sy);
extern int access_prim_plgBlt_gc_failed(HsPtr);
extern void* access_prim_plgBlt_gc_failstring(HsPtr);
extern void* prim_textOut(HDC arg1,INT arg2,INT arg3,char * arg4,int arg5);
extern int access_prim_textOut_gc_failed(HsPtr);
extern void* access_prim_textOut_gc_failstring(HsPtr);
extern void* prim_getTextExtentPoint32(HDC hdc,char * str,int l);
extern LONG access_prim_getTextExtentPoint32_gc_res1(HsPtr);
extern LONG access_prim_getTextExtentPoint32_gc_res2(HsPtr);
extern int access_prim_getTextExtentPoint32_gc_failed(HsPtr);
extern void* access_prim_getTextExtentPoint32_gc_failstring(HsPtr);
